
#ifndef _C15_et736_
#define _C15_et736_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_INTEGER_32 F1675_16619(EIF_REFERENCE);
extern void F1675_16621(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit736(void);

#ifdef __cplusplus
}
#endif

#endif
